@@ -9,7 +9,8 @@
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
+ *   the Free Software Foundation; either either version 2
+   of the License, or (at your option) any later version.of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   You should have received a copy of the GNU General Public License
@@ -22,12 +23,12 @@
 
 #include "GameLogic/onu.h"
 
-#include <KLocale>
-#include <KDebug>
-#include <KStandardDirs>
+#include <KLocalizedString>
+#include "ksirk_debug.h"
+#include <QStandardPaths>
 #include <KMessageBox>
 #include <KConfigDialog>
-#include <knewstuff3/downloaddialog.h>
+#include <downloaddialog.h>
 
 #include <qdir.h>
 #include <qstringlist.h>
@@ -43,7 +44,7 @@ NewGameWidget::NewGameWidget(NewGameSetup* newGameSetup, QWidget *parent) :
     Ui::NewGameDialog(),
     m_newGameSetup(newGameSetup)
 {
-  kDebug();
+  qCDebug(KSIRK_LOG);
   setupUi(this);
   
   QObject::connect(nextButton, SIGNAL(clicked()), this, SLOT(slotOK()) );
@@ -55,7 +56,7 @@ NewGameWidget::NewGameWidget(NewGameSetup* newGameSetup, QWidget *parent) :
 
 void NewGameWidget::init(const QString& skin, GameAutomaton::NetworkGameType netGameType)
 {
-  kDebug() << "Skin got: " << skin << " ; network=" << netGameType;
+  qCDebug(KSIRK_LOG) << "Skin got: " << skin << " ; network=" << netGameType;
   m_newGameSetup->setSkin(skin);
   if (netGameType != GameAutomaton::None)
   {
@@ -96,7 +97,7 @@ NewGameWidget::~NewGameWidget()
 
 void NewGameWidget::slotOK()
 {
-  kDebug() << "  skin is " << m_newGameSetup->worlds()[skinCombo->currentText()]->skin();
+  qCDebug(KSIRK_LOG) << "  skin is " << m_newGameSetup->worlds()[skinCombo->currentText()]->skin();
 //   m_networkGame  = networkGameCheckBox->isChecked();
   m_newGameSetup->setSkin(m_newGameSetup->worlds()[skinCombo->currentText()]->skin());
   m_newGameSetup->setNbPlayers(playersNumberEntry->value());
@@ -107,25 +108,23 @@ void NewGameWidget::slotOK()
 
 void NewGameWidget::slotCancel()
 {
-  kDebug();
+  qCDebug(KSIRK_LOG);
   emit newGameKO();
 }
 
 void NewGameWidget::fillSkinsCombo()
 {
-  kDebug() << "Filling skins combo";
+  qCDebug(KSIRK_LOG) << "Filling skins combo";
 
   skinCombo->clear();
   qDeleteAll(m_newGameSetup->worlds());
   
-  KStandardDirs *m_dirs = KGlobal::dirs();
-  QStringList skinsDirs = m_dirs->findDirs("appdata","skins");
-  kDebug() << skinsDirs;
+  QStringList skinsDirs = QStandardPaths::locateAll(QStandardPaths::AppDataLocation, "skins", QStandardPaths::LocateDirectory);
+  qCDebug(KSIRK_LOG) << skinsDirs;
   uint skinNum = 0;
   uint currentSkinNum = 0;
   foreach (const QString &skinsDirName, skinsDirs)
   {
-  //   QString skinsDirName = m_dirs->findResourceDir("appdata", "skins/skinsdir");
     if (skinsDirName.isEmpty())
     {
       KMessageBox::error(0,
@@ -133,25 +132,25 @@ void NewGameWidget::fillSkinsCombo()
                         i18n("Fatal Error!"));
       exit(2);
     }
-    kDebug() << "Got skins dir name: " << skinsDirName;
+    qCDebug(KSIRK_LOG) << "Got skins dir name: " << skinsDirName;
     QDir skinsDir(skinsDirName);
     QStringList skinsDirsNames = skinsDir.entryList(QStringList("[a-zA-Z]*"), QDir::Dirs);
 
     foreach (const QString& name, skinsDirsNames)
     {
-      kDebug() << "Got skin dir name: " << name;
-      QDir skinDir(skinsDirName + name);
+      qCDebug(KSIRK_LOG) << "Got skin dir name: " << name;
+      QDir skinDir(skinsDirName + '/' + name);
       if (skinDir.exists())
       {
-        kDebug() << "Got skin dir: " << skinDir.dirName();
-        GameLogic::ONU* world = new GameLogic::ONU(m_newGameSetup->automaton(),skinsDirName + skinDir.dirName() + "/Data/world.desktop");
+        qCDebug(KSIRK_LOG) << "Got skin dir: " << skinDir.dirName();
+        GameLogic::ONU* world = new GameLogic::ONU(m_newGameSetup->automaton(),skinsDirName + '/' + skinDir.dirName() + "/Data/world.desktop");
         if (!world->skin().isEmpty())
         {
           skinCombo->addItem(i18n(world->name().toUtf8().data()));
           m_newGameSetup->worlds()[i18n(world->name().toUtf8().data())] = world;
           if (QString(QLatin1String("skins/")+skinDir.dirName()) == m_newGameSetup->skin())
           {
-            kDebug() << "Setting currentSkinNum to " << skinNum;
+            qCDebug(KSIRK_LOG) << "Setting currentSkinNum to " << skinNum;
             currentSkinNum = skinNum;
           }
         }
@@ -168,7 +167,7 @@ void NewGameWidget::fillSkinsCombo()
 
 void NewGameWidget::slotSkinChanged(int skinNum)
 {
-    kDebug() << "NewGameDialogImpl::slotSkinChanged " 
+    qCDebug(KSIRK_LOG) << "NewGameDialogImpl::slotSkinChanged " 
               << skinNum << " ; " << skinCombo->currentText() 
               << " ; " << m_newGameSetup->worlds()[skinCombo->currentText()]->name() << " ; "
               << m_newGameSetup->worlds()[skinCombo->currentText()]->description();
@@ -183,11 +182,13 @@ void NewGameWidget::slotSkinChanged(int skinNum)
 
 void NewGameWidget::slotGHNS()
 {
-  if ( KConfigDialog::showDialog("settings") )
-  {
-    return;
-  }
-  kDebug();
+  // Bug 281294. No need to touch ConfigDialog.
+  // Skins are handled by KNS3 dialog.
+  // if ( KConfigDialog::showDialog("settings") )
+  // {
+  //   return;
+  // }
+  qCDebug(KSIRK_LOG);
   KNS3::DownloadDialog dialog(this);
   dialog.exec();
   
@@ -212,4 +213,4 @@ void NewGameWidget::slotNbNetworkPlayersEdited(int)
 
 }
 
-#include "newGameDialogImpl.moc"
+
